@@ -5,7 +5,7 @@ from sigma.conversion.deferred import DeferredTextQueryExpression
 from sigma.conditions import ConditionFieldEqualsValueExpression, ConditionOR
 from sigma.types import SigmaCompareExpression
 from sigma.exceptions import SigmaFeatureNotSupportedByBackendError
-from sigma.pipelines.splunk.splunk import splunk_sysmon_process_creation_dm_mapping, splunk_windows_registry_dm_mapping, splunk_windows_file_event_dm_mapping
+from sigma.pipelines.splunk.splunk import splunk_sysmon_process_creation_cim_mapping, splunk_windows_registry_cim_mapping, splunk_windows_file_event_cim_mapping
 import sigma
 from typing import ClassVar, Dict, List, Optional, Tuple
 
@@ -103,32 +103,49 @@ dispatch.latest_time = {self.max_time}
 """ + "\n".join(queries)
 
     def finalize_query_data_model(self, rule: SigmaRule, query: str, index: int, state: ConversionState) -> str:
+        data_model = None
+        data_set = None
+        cim_fields = None
         if rule.logsource.product and rule.logsource.category:
             if rule.logsource.product == "windows":
                 if rule.logsource.category == "process_creation":
                     data_model = 'Endpoint'
                     data_set = 'Processes'
-                    cim_fields = " ".join(splunk_sysmon_process_creation_dm_mapping.values())
+                    cim_fields = " ".join(splunk_sysmon_process_creation_cim_mapping.values())
                 elif rule.logsource.category in ["registry_add", "registry_delete", "registry_event", "registry_set"]:
                     data_model = 'Endpoint'
                     data_set = 'Registry'
-                    cim_fields = " ".join(splunk_windows_registry_dm_mapping.values())
+                    cim_fields = " ".join(splunk_windows_registry_cim_mapping.values())
                 elif rule.logsource.category == "file_event":
                     data_model = 'Endpoint'
                     data_set = 'Filesystem'
-                    cim_fields = " ".join(splunk_windows_file_event_dm_mapping.values())
+                    cim_fields = " ".join(splunk_windows_file_event_cim_mapping.values())
             elif rule.logsource.product == "linux":
                 if rule.logsource.category == "process_creation":
                     data_model = 'Endpoint'
                     data_set = 'Processes'
-                    cim_fields = " ".join(splunk_sysmon_process_creation_dm_mapping.values())
+                    cim_fields = " ".join(splunk_sysmon_process_creation_cim_mapping.values())
 
-        data_model_query = f"""| tstats summariesonly=false allow_old_summaries=true fillnull_value="null" count min(_time) as firstTime max(_time) as lastTime from datamodel={data_model}.{data_set} where {query} by {cim_fields}
+        try:
+            data_model_set = state.processing_state["data_model_set"]
+        except KeyError:
+            raise SigmaFeatureNotSupportedByBackendError("No data model specified by processing pipeline")
+
+        try:
+            data_set = data_model_set.split(".")[1]
+        except IndexError:
+            raise SigmaFeatureNotSupportedByBackendError("No data set specified by processing pipeline")
+
+        try:
+            fields = " ".join(state.processing_state["fields"])
+        except KeyError:
+            raise SigmaFeatureNotSupportedByBackendError("No fields specified by processing pipeline")
+
+        return f"""| tstats summariesonly=false allow_old_summaries=true fillnull_value="null" count min(_time) as firstTime max(_time) as lastTime from datamodel={data_model_set} where {query} by {fields}
 | `drop_dm_object_name({data_set})`
 | convert timeformat="%Y-%m-%dT%H:%M:%S" ctime(firstTime)
 | convert timeformat="%Y-%m-%dT%H:%M:%S" ctime(lastTime)
 """.replace("\n", " ")
-        return data_model_query
 
     def finalize_output_data_model(self, queries: List[str]) -> List[str]:
         return queries
\ No newline at end of file
