@@ -1,5 +1,13 @@
-from sigma.pipelines.common import logsource_windows
-from sigma.processing.transformations import AddConditionTransformation, FieldMappingTransformation, DetectionItemFailureTransformation, RuleFailureTransformation
+from sigma.pipelines.common import \
+    logsource_windows, \
+    logsource_windows_process_creation, \
+    logsource_windows_registry_add, \
+    logsource_windows_registry_delete, \
+    logsource_windows_registry_event, \
+    logsource_windows_registry_set, \
+    logsource_windows_file_event, \
+    logsource_linux_process_creation
+from sigma.processing.transformations import AddConditionTransformation, FieldMappingTransformation, DetectionItemFailureTransformation, RuleFailureTransformation, SetStateTransformation
 from sigma.processing.conditions import LogsourceCondition, IncludeFieldCondition, ExcludeFieldCondition, RuleProcessingItemAppliedCondition
 from sigma.processing.pipeline import ProcessingItem, ProcessingPipeline
 
@@ -31,7 +39,7 @@ windows_sysmon_acceleration_keywords = {    # Map Sysmon event sources and keywo
    "file_event": "TargetFilename",
 }
 
-splunk_sysmon_process_creation_dm_mapping = {
+splunk_sysmon_process_creation_cim_mapping = {
     "CommandLine": "Processes.process",
     "Computer": "Processes.dest",
     "CurrentDirectory": "Processes.process_current_directory",
@@ -46,7 +54,7 @@ splunk_sysmon_process_creation_dm_mapping = {
     "User": "Processes.user",
 }
 
-splunk_windows_registry_dm_mapping = {
+splunk_windows_registry_cim_mapping = {
     "Computer": "Registry.dest",
     "Details": "Registry.registry_value_data",
     "EventType": "Registry.action", # EventType: DeleteKey is parsed to action: deleted
@@ -56,7 +64,7 @@ splunk_windows_registry_dm_mapping = {
     "TargetObject": "Registry.registry_key_name",
 }
 
-splunk_windows_file_event_dm_mapping = {
+splunk_windows_file_event_cim_mapping = {
     "Computer": "Filesystem.dest",
     "CreationUtcTime": "Filesystem.file_create_time",
     "Image": "Filesystem.process_path",
@@ -65,49 +73,6 @@ splunk_windows_file_event_dm_mapping = {
     "TargetFilename": "Filesystem.file_path",
 }
 
-
-def logsource_windows_process_creation():
-    return LogsourceCondition(
-        category="process_creation",
-        product="windows",
-    )
-
-def logsource_windows_registry_add():
-    return LogsourceCondition(
-        category="registry_add",
-        product="windows",
-    )
-
-def logsource_windows_registry_delete():
-    return LogsourceCondition(
-        category="registry_delete",
-        product="windows",
-    )
-
-def logsource_windows_registry_event():
-    return LogsourceCondition(
-        category="registry_event",
-        product="windows",
-    )
-
-def logsource_windows_registry_set():
-    return LogsourceCondition(
-        category="registry_set",
-        product="windows",
-    )
-
-def logsource_windows_file_event():
-    return LogsourceCondition(
-        category="file_event",
-        product="windows",
-    )
-
-def logsource_linux_process_creation():
-    return LogsourceCondition(
-        category="process_creation",
-        product="linux",
-    )
-
 def splunk_windows_pipeline():
     return ProcessingPipeline(
         name="Splunk Windows log source conditions",
@@ -151,14 +116,14 @@ def splunk_windows_sysmon_acceleration_keywords():
         ]
     )
 
-def splunk_data_model():
+def splunk_cim_data_model():
     return ProcessingPipeline(
-        name="Splunk Data Model Mapping for Sysmon Process Creation",
+        name="Splunk CIM Data Model Mapping",
         priority=20,
         items=[
             ProcessingItem(
                 identifier="splunk_dm_mapping_sysmon_process_creation_unsupported_fields",
-                transformation=DetectionItemFailureTransformation("The Splunk Data Model Sigma backend supports only the following fields for process_creation log source: " + ",".join(splunk_sysmon_process_creation_dm_mapping.keys())),
+                transformation=DetectionItemFailureTransformation("The Splunk Data Model Sigma backend supports only the following fields for process_creation log source: " + ",".join(splunk_sysmon_process_creation_cim_mapping.keys())),
                 rule_conditions=[
                     logsource_windows_process_creation(),
                     logsource_linux_process_creation(),
@@ -166,13 +131,31 @@ def splunk_data_model():
                 rule_condition_linking=any,
                 detection_item_conditions=[
                     ExcludeFieldCondition(
-                        fields = splunk_sysmon_process_creation_dm_mapping.keys()
+                        fields = splunk_sysmon_process_creation_cim_mapping.keys()
                     )
                 ]
             ),
             ProcessingItem(
                 identifier="splunk_dm_mapping_sysmon_process_creation",
-                transformation=FieldMappingTransformation(splunk_sysmon_process_creation_dm_mapping),
+                transformation=FieldMappingTransformation(splunk_sysmon_process_creation_cim_mapping),
+                rule_conditions=[
+                    logsource_windows_process_creation(),
+                    logsource_linux_process_creation(),
+                ],
+                rule_condition_linking=any,
+            ),
+            ProcessingItem(
+                identifier="splunk_dm_fields_sysmon_process_creation",
+                transformation=SetStateTransformation("fields", splunk_sysmon_process_creation_cim_mapping.values()),
+                rule_conditions=[
+                    logsource_windows_process_creation(),
+                    logsource_linux_process_creation(),
+                ],
+                rule_condition_linking=any,
+            ),
+            ProcessingItem(
+                identifier="splunk_dm_sysmon_process_creation_data_model_set",
+                transformation=SetStateTransformation("data_model_set", "Endpoint.Processes"),
                 rule_conditions=[
                     logsource_windows_process_creation(),
                     logsource_linux_process_creation(),
@@ -181,7 +164,7 @@ def splunk_data_model():
             ),
             ProcessingItem(
                 identifier="splunk_dm_mapping_sysmon_registry_unsupported_fields",
-                transformation=DetectionItemFailureTransformation("The Splunk Data Model Sigma backend supports only the following fields for registry log source: " + ",".join(splunk_windows_registry_dm_mapping.keys())),
+                transformation=DetectionItemFailureTransformation("The Splunk Data Model Sigma backend supports only the following fields for registry log source: " + ",".join(splunk_windows_registry_cim_mapping.keys())),
                 rule_conditions=[
                     logsource_windows_registry_add(),
                     logsource_windows_registry_delete(),
@@ -191,13 +174,35 @@ def splunk_data_model():
                 rule_condition_linking=any,
                 detection_item_conditions=[
                     ExcludeFieldCondition(
-                        fields = splunk_windows_registry_dm_mapping.keys()
+                        fields = splunk_windows_registry_cim_mapping.keys()
                     )
                 ]
             ),
             ProcessingItem(
                 identifier="splunk_dm_mapping_sysmon_registry",
-                transformation=FieldMappingTransformation(splunk_windows_registry_dm_mapping),
+                transformation=FieldMappingTransformation(splunk_windows_registry_cim_mapping),
+                rule_conditions=[
+                    logsource_windows_registry_add(),
+                    logsource_windows_registry_delete(),
+                    logsource_windows_registry_event(),
+                    logsource_windows_registry_set(),
+                ],
+                rule_condition_linking=any,
+            ),
+            ProcessingItem(
+                identifier="splunk_dm_fields_sysmon_registry",
+                transformation=SetStateTransformation("fields", splunk_windows_registry_cim_mapping.values()),
+                rule_conditions=[
+                    logsource_windows_registry_add(),
+                    logsource_windows_registry_delete(),
+                    logsource_windows_registry_event(),
+                    logsource_windows_registry_set(),
+                ],
+                rule_condition_linking=any,
+            ),
+            ProcessingItem(
+                identifier="splunk_dm_sysmon_registry_data_model_set",
+                transformation=SetStateTransformation("data_model_set", "Endpoint.Registry"),
                 rule_conditions=[
                     logsource_windows_registry_add(),
                     logsource_windows_registry_delete(),
@@ -208,19 +213,33 @@ def splunk_data_model():
             ),
             ProcessingItem(
                 identifier="splunk_dm_mapping_sysmon_file_event_unsupported_fields",
-                transformation=DetectionItemFailureTransformation("The Splunk Data Model Sigma backend supports only the following fields for file_event log source: " + ",".join(splunk_windows_file_event_dm_mapping.keys())),
+                transformation=DetectionItemFailureTransformation("The Splunk Data Model Sigma backend supports only the following fields for file_event log source: " + ",".join(splunk_windows_file_event_cim_mapping.keys())),
                 rule_conditions=[
                     logsource_windows_file_event(),
                 ],
                 detection_item_conditions=[
                     ExcludeFieldCondition(
-                        fields = splunk_windows_file_event_dm_mapping.keys()
+                        fields = splunk_windows_file_event_cim_mapping.keys()
                     )
                 ]
             ),
             ProcessingItem(
                 identifier="splunk_dm_mapping_sysmon_file_event",
-                transformation=FieldMappingTransformation(splunk_windows_file_event_dm_mapping),
+                transformation=FieldMappingTransformation(splunk_windows_file_event_cim_mapping),
+                rule_conditions=[
+                    logsource_windows_file_event(),
+                ]
+            ),
+            ProcessingItem(
+                identifier="splunk_dm_fields_sysmon_file_event",
+                transformation=SetStateTransformation("fields", splunk_windows_file_event_cim_mapping.values()),
+                rule_conditions=[
+                    logsource_windows_file_event(),
+                ]
+            ),
+            ProcessingItem(
+                identifier="splunk_dm_mapping_sysmon_file_event_data_model_set",
+                transformation=SetStateTransformation("data_model_set", "Endpoint.Filesystem"),
                 rule_conditions=[
                     logsource_windows_file_event(),
                 ]
@@ -228,7 +247,7 @@ def splunk_data_model():
             ProcessingItem(
                 identifier="splunk_dm_mapping_log_source_not_supported",
                 rule_condition_linking=any,
-                transformation=RuleFailureTransformation("Rule type not yet supported by the Splunk Data Model Sigma backend!"),
+                transformation=RuleFailureTransformation("Rule type not yet supported by the Splunk data model CIM pipeline!"),
                 rule_condition_negation=True,
                 rule_conditions=[
                     RuleProcessingItemAppliedCondition("splunk_dm_mapping_sysmon_process_creation"),
